# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.1](https://github.com/starsoi/trazer/compare/v0.2.0...v0.2.1) (2021-11-29)


### Bug Fixes

* flow works for slices in different processes ([ad84779](https://github.com/starsoi/trazer/commit/ad847794961afbdf0be9b0f2dbd3ebeac3a2ac50))

## [0.2.0](https://github.com/starsoi/trazer/compare/v0.1.0...v0.2.0) (2021-11-28)


### Features

* support flow events connecting durations ([6edb2d1](https://github.com/starsoi/trazer/commit/6edb2d1576197ccf7f69daeaa49c3913d6bd293a))
* support name assignment to processes and threads ([9f26b6b](https://github.com/starsoi/trazer/commit/9f26b6b9d5a198e332a9e85a1e685d3f8466fa3f))


### Bug Fixes

* consistent unit for timestamp ([e10fa57](https://github.com/starsoi/trazer/commit/e10fa571fc1d4615245a7731e66503ec5a81b629))

### [0.1.0](https://github.com/starsoi/tree/v0.1.0) (2021-05-24)

👏 First release 👏

#### Features

* Create execution trace programmatically
* Find event chains using event pattern
* Export trace together with event chains to Chrome trace JSON
